@@ -18,11 +18,11 @@ Template::Flute - Modern designer-friendly HTML templating Engine
 
 =head1 VERSION
 
-Version 0.0097
+Version 0.0098
 
 =cut
 
-our $VERSION = '0.0097';
+our $VERSION = '0.0098';
 
 =head1 SYNOPSIS
 
@@ -477,14 +477,13 @@ sub _sub_process {
 		my $list = $template->{lists}->{$spec_name};
 		my $count = 1;
 		for my $record_values (@$records){
-			
 			my $element = $element_template->copy();
 			$element = $self->_sub_process($element, $sub_spec, $record_values, undef, undef, $count, $level + 1);
-			
+
 			# Get rid of flutexml container and put it into position
 			for my $e (reverse($element->cut_children())) {
 				$e->paste(%paste_pos);
-       		}				
+       		}
 
 			# Add separator
 			if ($list->{separators}) {
@@ -495,23 +494,24 @@ sub _sub_process {
 					    last;
 					}
 			    }
-			}	
-			$count++;		
-		}
-		$element_template->cut(); # Remove template element
-			
-			if ($sep_copy) {
-			    # Remove last separator and original one(s) in the template
-			    $sep_copy->cut();
-			    
-			    for my $sep (@{$list->{separators}}) {
-					for my $elt (@{$sep->{elts}}) {
-					    $elt->cut();
-					}
-			    }
 			}
+			$count++;
 		}
-		
+
+		$element_template->cut(); # Remove template element
+
+        if ($sep_copy) {
+            # Remove last separator and original one(s) in the template
+            $sep_copy->cut();
+
+            for my $sep (@{$list->{separators}}) {
+                for my $elt (@{$sep->{elts}}) {
+                    $elt->cut();
+                }
+            }
+        }
+    }
+
 	# Values
 	for my $elt ( @{$spec_elements->{value}}, @{$spec_elements->{param}}, @{$spec_elements->{field}} ){	
         if ($elt->tag eq 'param') {
@@ -535,9 +535,6 @@ sub _sub_process {
 		else {
 			$spec_clases = $classes->{$spec_class};
 		}
-		if ($spec_name eq 'label'){
-			1;
-		}
 		
 		for my $spec_class (@$spec_clases){
             # check if we need an iterator for this element
@@ -1469,6 +1466,8 @@ a documentation fix.
 
 Thanks to Ton Verhagen for being a big supporter of my projects in all aspects.
 
+Thanks to Sam Batschelet helping me with a bug causing duplicate form fields (GH #14).
+
 Thanks to Terrence Brannon for spotting a documentation mix-up.
 
 =head1 HISTORY
